eggbasket.odict

Package eggbasket :: Module odict |
[show private | hide private]
[frames | no frames]

## Module eggbasket.odict

A dict that keeps keys in insertion order

Classes
`OrderedDict` | A class of dictionary that keeps the insertion order of keys.
`SequenceOrderedDict` | Experimental version of OrderedDict that has a custom object for `keys`, `values`, and `items`.
`Items` | Custom object for accessing the items of an OrderedDict.
`Keys` | Custom object for accessing the keys of an OrderedDict.
`Values` | Custom object for accessing the values of an OrderedDict.

Generated by Epydoc 2.1 on Mon Apr 21 14:16:57 2008 | http://epydoc.sf.net